pub struct InvokeCpiWrapper(pub InstructionDataInvokeCpi);Expand description
Wrapper type for InvokeCpi instruction that handles the 4-byte Anchor prefix.
Tuple Fields
0: InstructionDataInvokeCpiTrait Implementations
Sourceimpl BorshDeserialize for InvokeCpiWrapper
impl BorshDeserialize for InvokeCpiWrapper
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,