pub struct InvokeWrapper(pub InstructionDataInvoke);Expand description
Wrapper type for Invoke instruction that handles the 4-byte Anchor prefix.
The derive macro’s borsh deserialization expects the data immediately after the discriminator, but Invoke/InvokeCpi have a 4-byte vec length prefix. This wrapper type’s deserialize implementation skips those 4 bytes.
Tuple Fields
0: InstructionDataInvokeTrait Implementations
Sourceimpl BorshDeserialize for InvokeWrapper
impl BorshDeserialize for InvokeWrapper
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,